#!/bin/sh
#
# Tweak the console to make it more usable after a standard Debian installation
# Written by Jens Vogel in 2011
# http://www.desktux.nl/

# Variables
. /etc/profile
white="[1;37m"
reset="[0m"

# Check some parameters
if [ $(whoami) != "root" ]; then
	echo "${white}Please run me as root!${reset}"
	exit 1
fi
if [ ! -f $(pwd)/$(basename ${0}) ]; then
	echo "${white}Please 'cd' to the directory containing this script!${reset}"
	exit 1
fi
chown -R root:root *

# Install a new sources.list and update system
clear
echo "${white}Installing new sources.list and updating system...${reset}"
cp -f conf/sources.list /etc/apt
apt-get update
apt-get -y --force-yes install pkg-mozilla-archive-keyring
apt-get -y --force-yes dist-upgrade

# Install and remove necessary packages
echo "${white}Cleaning up packaging system... just accept the default values when being asked.${reset}"
apt-get -y install deborphan fortunes less linuxlogo nullmailer psmisc screen ssh vim zsh
apt-get -y remove --purge ed nano nfs-common portmap vim-tiny w3m
apt-get -y autoremove --purge
while [ "$(deborphan)" ]; do
	apt-get -y remove --purge $(deborphan)
done
dpkg -P $(dpkg --get-selections|grep deinstall|cut -f1)

# Configure packages
echo "${white}Configuring system...${reset}"
cp -f conf/zsh/* /etc/zsh
chsh -s /bin/zsh
sed -i '{
	s/"syntax on/syntax on/
	s/"set background=dark/set background=dark/
	s/"set showcmd/set showcmd/
	s/"set showmatch/set showmatch/
	s/"set ignorecase/set ignorecase/
	s/"set smartcase/set smartcase/
	s/"set incsearch/set incsearch/
	s/"set autowrite/set autowrite/
	s/"set hidden/set hidden/
}' /etc/vim/vimrc
sed -i 's/agetty/agetty -f \/etc\/issue.linuxlogo/' /etc/systemd/system/getty.target.wants/getty@tty1.service
sed -i 's/# en_DK.UTF-8 UTF-8/en_DK.UTF-8 UTF-8/' /etc/locale.gen
sed -i 's/#send host-name "andare.fugue.com";/send host-name "'$(hostname)'";/' /etc/dhcp/dhclient.conf
sed -i '
	s/GRUB_TIMEOUT=5/GRUB_TIMEOUT=3/
	s/#GRUB_GFXMODE=640x480/GRUB_GFXMODE=1920x1080\nGRUB_GFXPAYLOAD_LINUX=keep/
' /etc/default/grub
update-grub
sed -i '
	s/LANG="en_US.UTF-8"/LANG="en_DK.UTF-8"/
	s/LANGUAGE="en_US:en"/LANGUAGE="en_DK:en"/
' /etc/default/locale
locale-gen
echo $(uname -a) > /etc/motd
echo >> /etc/motd
echo > /etc/motd.tail

# Done
clear
echo "${white}All done!${reset}"
echo "${white}To activate all changes a reboot is required. Please enter 'y' to reboot now,${reset}"
echo -n "${white}or any other character to return to the shell: ${reset}"
read reboot
if [ $reboot = "y" ]; then
	reboot
fi
exit 0
